@@ -16,7 +16,7 @@ use DynaLoader();
 use Carp ();
 @ISA = qw(DynaLoader);
 
-$VERSION = '2.0205';
+$VERSION = '2.0206';
 
 bootstrap DBD::mSQL $VERSION;
 
@@ -295,7 +295,7 @@ Interface (DBI)
     use DBI;
 
     $driver = "mSQL"; # or "mSQL1";
-    $dsn = "DBI:$driver:database=$database;host=$hostname;port=$port";
+    $dsn = "DBI:$driver:database=$database;host=$hostname";
 
     $dbh = DBI->connect($dsn,	undef, undef);
 
@@ -377,6 +377,20 @@ Should the mysql or mSQL daemon be running on a non-standard port number,
 you may explicitly state the port number to connect to in the C<hostname>
 argument, by concatenating the I<hostname> and I<port number> together
 separated by a colon ( C<:> ) character or by using the  C<port> argument.
+This doesn't work for mSQL 2: You have to create an alternative config
+file and load it using the msql_configfile attribute, see below.
+
+=item msql_configfile
+
+By default mSQL 2 loads its port settings and similar things from the
+file InstDir/msql.conf. This option allows you to specify another
+attribute, as in
+
+    DBI->connect("DBI:mSQL:test;msql_configfile=msql_test.conf");
+
+If the filename is not absolute, mSQL will search in certain other
+locations, see the documentation of the msqlLoadConfigFile() function
+in the mSQL manual for details.
 
 =item mysql_compression
 
